@@ -67,6 +67,9 @@ module LogStash module Config
         raise LogStash::ConfigLoadingError, I18n.t("logstash.modules.configuration.modules-unavailable", **i18n_opts)
       end
 
+      specified_and_available_names
+        .each { |mn| deprecation_logger.deprecated("The #{mn} module has been deprecated and will be removed in version 9.") }
+
       specified_and_available_names.each do |module_name|
         connect_fail_args = {}
         begin
