@@ -21,11 +21,13 @@ module LogStash; module Config;
       # It is important that we iterate via the agent's pipelines vs. the
       # metrics pipelines. This prevents race conditions as pipeline stats may be
       # populated before the agent has it in its own pipelines state
-      stats = metric_store.get_with_path("/stats/pipelines")[:stats][:pipelines]
+      stats = metric_store.get_with_path("/stats/pipelines").dig(:stats, :pipelines) || {}
       agent.running_pipelines.map do |pipeline_id, pipeline|
-        p_stats = stats[pipeline_id]
+        p_stats = stats.fetch(pipeline_id) { Hash.new }
         # Don't record stats for system pipelines
         next nil if pipeline.system?
+        # Don't emit stats for pipelines that have not yet registered any metrics
+        next nil if p_stats.nil?
         res = {
           "id" => pipeline_id.to_s,
           "hash" => pipeline.lir.unique_hash,
@@ -33,8 +35,8 @@ module LogStash; module Config;
           "events" => format_pipeline_events(p_stats[:events]),
           "queue" => format_queue_stats(pipeline_id, metric_store),
           "reloads" => {
-            "successes" => p_stats[:reloads][:successes].value,
-            "failures" => p_stats[:reloads][:failures].value
+            "successes" => (p_stats.dig(:reloads, :successes)&.value || 0),
+            "failures" => (p_stats.dig(:reloads, :failures)&.value || 0)
           }
         }
         if extended_performance_collection
@@ -52,7 +54,7 @@ module LogStash; module Config;
 
     def self.format_pipeline_vertex_stats(stats, pipeline)
       return nil unless stats
-      
+
       [:inputs, :filters, :outputs].flat_map do |section|
         format_pipeline_vertex_section_stats(stats[section], pipeline)
       end.select {|stats| !stats.nil?} # Ignore empty sections
@@ -68,17 +70,17 @@ module LogStash; module Config;
 
     def self.format_pipeline_vertex_section_stats(stats, pipeline)
       return nil unless stats
-      
-       (stats || {}).reduce([]) do |acc,kv|
+
+       (stats || {}).reduce([]) do |acc, kv|
         plugin_id, plugin_stats = kv
-        
-        props = Hash.new {|h,k| h[k] = []}
+
+        props = Hash.new {|h, k| h[k] = []}
         next unless plugin_stats
-        
+
         flattened = flatten_metrics(plugin_stats)
 
-        segmented = flattened.reduce(Hash.new {|h,k| h[k] = []}) do |acc,kv|
-          k,v = kv
+        segmented = flattened.reduce(Hash.new {|h, k| h[k] = []}) do |acc, kv|
+          k, v = kv
           metric_value = v.value
           root_metric_field = ROOT_METRIC_MAPPINGS[k]
 
@@ -122,8 +124,8 @@ module LogStash; module Config;
 
     def self.flatten_metrics(hash_or_value, namespaces = [])
       if hash_or_value.is_a?(Hash)
-        return hash_or_value.reduce({}) do |acc,kv| 
-          k,v = kv
+        return hash_or_value.reduce({}) do |acc, kv|
+          k, v = kv
           # We must concat the arrays, creating a copy instead of mutation
           # to handle the case where there are multiple sibling metrics in a namespace
           new_namespaces = namespaces.clone
