@@ -39,7 +39,6 @@ module LogStash; class JavaPipeline < AbstractPipeline
     :started_at,
     :thread
 
-  MAX_INFLIGHT_WARN_THRESHOLD = 10_000
   SECOND = 1
   MEMORY = "memory".freeze
 
@@ -65,6 +64,7 @@ module LogStash; class JavaPipeline < AbstractPipeline
     @flushing = java.util.concurrent.atomic.AtomicBoolean.new(false)
     @flushRequested = java.util.concurrent.atomic.AtomicBoolean.new(false)
     @shutdownRequested = java.util.concurrent.atomic.AtomicBoolean.new(false)
+    @crash_detected = Concurrent::AtomicBoolean.new(false)
     @outputs_registered = Concurrent::AtomicBoolean.new(false)
 
     # @finished_execution signals that the pipeline thread has finished its execution
@@ -87,6 +87,10 @@ module LogStash; class JavaPipeline < AbstractPipeline
     @finished_execution.true?
   end
 
+  def finished_run?
+    @finished_run.true?
+  end
+
   def ready?
     @ready.value
   end
@@ -229,6 +233,10 @@ module LogStash; class JavaPipeline < AbstractPipeline
     @running.false?
   end
 
+  def crashed?
+    @crash_detected.true?
+  end
+
   # register_plugins calls #register_plugin on the plugins list and upon exception will call Plugin#do_close on all registered plugins
   # @param plugins [Array[Plugin]] the list of plugins to register
   def register_plugins(plugins)
@@ -275,10 +283,6 @@ module LogStash; class JavaPipeline < AbstractPipeline
         "pipeline.sources" => pipeline_source_details)
       @logger.info("Starting pipeline", pipeline_log_params)
 
-      if max_inflight > MAX_INFLIGHT_WARN_THRESHOLD
-        @logger.warn("CAUTION: Recommended inflight events max exceeded! Logstash will run with up to #{max_inflight} events in memory in your current configuration. If your message sizes are large this may cause instability with the default heap size. Please consider setting a non-standard heap size, changing the batch size (currently #{batch_size}), or changing the number of pipeline workers (currently #{pipeline_workers})", default_logging_keys)
-      end
-
       filter_queue_client.set_batch_dimensions(batch_size, batch_delay)
 
       # First launch WorkerLoop initialization in separate threads which concurrently
@@ -305,6 +309,7 @@ module LogStash; class JavaPipeline < AbstractPipeline
           rescue => e
             # WorkerLoop.run() catches all Java Exception class and re-throws as IllegalStateException with the
             # original exception as the cause
+            @crash_detected.make_true
             @logger.error(
               "Pipeline worker error, the pipeline will be stopped",
               default_logging_keys(:error => e.cause.message, :exception => e.cause.class, :backtrace => e.cause.backtrace)
@@ -319,6 +324,7 @@ module LogStash; class JavaPipeline < AbstractPipeline
       begin
         start_inputs
       rescue => e
+        @crash_detected.make_true
         # if there is any exception in starting inputs, make sure we shutdown workers.
         # exception will already by logged in start_inputs
         shutdown_workers
@@ -628,7 +634,7 @@ module LogStash; class JavaPipeline < AbstractPipeline
     case settings.get("pipeline.ordered")
     when "auto"
       if settings.set?("pipeline.workers") && settings.get("pipeline.workers") == 1
-        @logger.warn("'pipeline.ordered' is enabled and is likely less efficient, consider disabling if preserving event order is not necessary")
+        @logger.warn("'pipeline.ordered' is enabled and is likely less efficient, consider disabling if preserving event order is not necessary") unless settings.get("pipeline.system")
         return true
       end
     when "true"
