@@ -92,10 +92,6 @@ class LogStash::Runner < Clamp::StrictCommand
          :default => LogStash::SETTINGS.get_default("config.field_reference.escape_style"),
          :attribute_name => "config.field_reference.escape_style"
 
-  option ["--event_api.tags.illegal"], "STRING",
-         I18n.t("logstash.runner.flag.event_api.tags.illegal"),
-         :default => LogStash::SETTINGS.get_default("event_api.tags.illegal"),
-         :attribute_name => "event_api.tags.illegal"
 
   # Module settings
   option ["--modules"], "MODULES",
@@ -257,15 +253,24 @@ class LogStash::Runner < Clamp::StrictCommand
 
   deprecated_option ["--http.enabled"], :flag,
     I18n.t("logstash.runner.flag.http_enabled"),
-    :new_flag => "api.enabled", :passthrough => true # use settings to disambiguate
+    :new_flag => "api.enabled", :passthrough => true, # use settings to disambiguate
+    :obsoleted_version => "9"
 
   deprecated_option ["--http.host"], "HTTP_HOST",
     I18n.t("logstash.runner.flag.http_host"),
-    :new_flag => "api.http.host", :passthrough => true # use settings to disambiguate
+    :new_flag => "api.http.host", :passthrough => true, # use settings to disambiguate
+    :obsoleted_version => "9"
 
   deprecated_option ["--http.port"], "HTTP_PORT",
     I18n.t("logstash.runner.flag.http_port"),
-    :new_flag => "api.http.port", :passthrough => true # use settings to disambiguate
+    :new_flag => "api.http.port", :passthrough => true, # use settings to disambiguate
+    :obsoleted_version => "9"
+
+  deprecated_option ["--event_api.tags.illegal"], "STRING",
+         I18n.t("logstash.runner.flag.event_api.tags.illegal"),
+         :default => LogStash::SETTINGS.get_default("event_api.tags.illegal"),
+         :attribute_name => "event_api.tags.illegal", :passthrough => true,
+         :obsoleted_version => "9"
 
   # We configure the registry and load any plugin that can register hooks
   # with logstash, this needs to be done before any operation.
@@ -310,9 +315,17 @@ class LogStash::Runner < Clamp::StrictCommand
     if setting("config.debug") && !logger.debug?
       logger.warn("--config.debug was specified, but log.level was not set to \'debug\'! No config info will be logged.")
     end
-    if setting("pipeline.buffer.type") != nil
-      configure_pipeline_buffer_type
+    if setting("pipeline.buffer.type") == nil
+      deprecation_logger.deprecated(
+        "'pipeline.buffer.type' setting is not explicitly defined."\
+        "Before moving to 9.x set it to 'heap' and tune heap size upward, or set it to 'direct' to maintain existing behavior."
+      )
+
+      # set to direct to keep backward ecs_compatibility
+      buffer_type_setting = @settings.get_setting("pipeline.buffer.type")
+      buffer_type_setting.set("direct")
     end
+    configure_pipeline_buffer_type
 
     while (msg = LogStash::DeprecationMessage.instance.shift)
       deprecation_logger.deprecated msg
@@ -321,6 +334,9 @@ class LogStash::Runner < Clamp::StrictCommand
     if JavaVersion::CURRENT < JavaVersion::JAVA_11
       logger.warn I18n.t("logstash.runner.java.version",
                                              :java_home => java.lang.System.getProperty("java.home"))
+    elsif JavaVersion::CURRENT < JavaVersion::JAVA_17
+      deprecation_logger.deprecated I18n.t("logstash.runner.java.version_17_minimum",
+                                           :java_home => java.lang.System.getProperty("java.home"))
     end
 
     logger.warn I18n.t("logstash.runner.java.home") if ENV["JAVA_HOME"]
@@ -337,8 +353,8 @@ class LogStash::Runner < Clamp::StrictCommand
     # Add local modules to the registry before everything else
     LogStash::Modules::Util.register_local_modules(LogStash::Environment::LOGSTASH_HOME)
 
-    # Set up the Jackson defaults
-    LogStash::Util::Jackson.set_jackson_defaults(logger)
+    # Verify the Jackson defaults
+    LogStash::Util::Jackson.verify_jackson_overrides
 
     @dispatcher = LogStash::EventDispatcher.new(self)
     LogStash::PLUGIN_REGISTRY.hooks.register_emitter(self.class, @dispatcher)
@@ -477,8 +493,15 @@ class LogStash::Runner < Clamp::StrictCommand
 
   def running_as_superuser
     if Process.euid() == 0
+      unless @settings.set?("allow_superuser")
+        deprecation_logger.deprecated("Starting from version 9.0, " +
+          "running with superuser privileges is not permitted unless you explicitly set 'allow_superuser' to true, " +
+          "thereby acknowledging the possible security risks")
+      end
+
       if setting("allow_superuser")
-        deprecation_logger.deprecated("NOTICE: Running Logstash as superuser is not recommended and won't be allowed in the future. Set 'allow_superuser' to 'false' to avoid startup errors in future releases.")
+        logger.warn("NOTICE: Running Logstash as a superuser is strongly discouraged as it poses a security risk. " +
+                      "Set 'allow_superuser' to false for better security.")
       else
         raise(RuntimeError, "Logstash cannot be run as superuser.")
       end
