@@ -30,12 +30,11 @@ require "logstash/environment"
 # The methods should be called in the above order before the settings are ready to be used.
 ########################
 module LogStash::Util::SettingsHelper
-
   # The `path.settings` and `path.logs` can not be defined in "logstash/environment" since the `Environment::LOGSTASH_HOME` doesn't
   # exist unless launched via "bootstrap/environment"
   def self.pre_process
-    LogStash::SETTINGS.register(LogStash::Setting::String.new("path.settings", ::File.join(LogStash::Environment::LOGSTASH_HOME, "config")))
-    LogStash::SETTINGS.register(LogStash::Setting::String.new("path.logs", ::File.join(LogStash::Environment::LOGSTASH_HOME, "logs")))
+    LogStash::SETTINGS.register(LogStash::Setting::SettingString.new("path.settings", ::File.join(LogStash::Environment::LOGSTASH_HOME, "config")))
+    LogStash::SETTINGS.register(LogStash::Setting::SettingString.new("path.logs", ::File.join(LogStash::Environment::LOGSTASH_HOME, "logs")))
   end
 
   # Ensure that any settings are re-calculated after loading yaml
@@ -76,8 +75,8 @@ module LogStash::Util::SettingsHelper
   # 3. check if the LS_SETTINGS_DIR environment variable is set
   # 4. return nil if not found
   def self.fetch_settings_path(cli_args)
-    if i=cli_args.find_index("--path.settings")
-      cli_args[i+1]
+    if i = cli_args.find_index("--path.settings")
+      cli_args[i + 1]
     elsif settings_arg = cli_args.find {|v| v.match(/--path.settings=/)}
       match = settings_arg.match(/--path.settings=(.*)/)
       match[1]
@@ -93,5 +92,4 @@ module LogStash::Util::SettingsHelper
     # I know, double negative
     !(["--help", "-h"] & args).empty?
   end
-
-end
\ No newline at end of file
+end
